@@ -340,8 +340,13 @@ class Command(object):
         pass
     
     def execute(self):
+        """Execute the command
+        
+        Returns:
+            Tuple (rc, "msg", {details})
+        """
         cmd = getattr(atropos.commands, self.name)
-        cmd(self.options, self.parser)
+        return cmd(self.options, self.parser)
 
 class TrimCommand(Command):
     """trim sequencing reads."""
@@ -542,12 +547,13 @@ standard input/output. Without the -o option, output is sent to standard output.
         group = parser.add_argument_group("Additional read modifications")
         group.add_argument(
             "--op-order",
-            type=char_list(choices=('W','A','C','G','Q')), default="WCGQA",
+            type=char_list(choices=('A','C','G','Q','W')), default="CGQAW",
             help="The order in which trimming operations are be applied. This is a string of "
-                 "1-5 of the following characters: W = overwrite poor quality reads; "
-                 "A = adapter trimming; C = cutting (unconditional); G = NextSeq trimming; "
-                 "Q = quality trimming. The default is 'WCGQA' to maintain compatibility with "
-                 "Cutadapt; however, this is likely to change to 'WGACQ' in the near future.")
+                 "1-5 of the following characters: A = adapter trimming; "
+                 "C = cutting (unconditional); G = NextSeq trimming; "
+                 "Q = quality trimming; W = overwrite poor quality reads. The "
+                 "default is 'WCGQA' to maintain compatibility with "
+                 "Cutadapt; however, this is likely to change to 'GAWCQ' in the near future.")
         group.add_argument(
             "-u",
             "--cut",
@@ -1180,17 +1186,18 @@ COMMANDS['error'] = ErrorCommand
 
 # Main
 
-def main(cmdlineargs=None):
-    """
-    Main function that evaluates command-line parameters.
+def main(args):
+    """Main function that evaluates command-line parameters.
     
-    :param cmdlineargs: iterable of command line arguments; `None` is equivalent to
-    `sys.argv[1:]`
+    Args:
+        args: list/tuple of command line arguments
+    
+    Returns:
+        Tuple (rc, "msg", {details})
     """
-    args = cmdlineargs or sys.argv[1:]
     if len(args) == 0 or any(h in args for h in ('-h', '--help')):
         print_subcommands()
-        return
+        return (2, None, {})
     
     if args[0][0] == '-':
         command_name = "trim"
@@ -1200,7 +1207,7 @@ def main(cmdlineargs=None):
     
     command_class = COMMANDS[command_name]
     command = command_class(args)
-    command.execute()
+    return command.execute()
 
 def print_subcommands():
     print("Atropos version {}\n".format(__version__))
@@ -1224,4 +1231,7 @@ EMBnet Journal, 2011, 17(1):10-12.
 """)
 
 if __name__ == '__main__':
-    main()
+    rc, message, _ = main(sys.argv[1:])
+    if message:
+        print(message)
+    sys.exit(rc)
