@@ -21,7 +21,8 @@ def temporary_path(name):
         os.mkdir(directory)
     path = os.path.join(directory, name)
     yield path
-    os.remove(path)
+    if os.path.exists(path):
+        os.remove(path)
 
 
 def datapath(path):
@@ -64,7 +65,9 @@ def run(params, expected, inpath, inpath2=None, qualfile=None, interleaved_input
         else:
             params += ['-o', tmp_fastaq] # TODO not parallelizable
         print(params)
-        assert atropos.main(params) is None
+        result = atropos.main(params)
+        assert isinstance(result, tuple)
+        assert len(result) == 3
         # TODO redirect standard output
         assert files_equal(cutpath(expected), tmp_fastaq)
     # TODO diff log files
